@@ -14,9 +14,14 @@ if False:
 
 
 class ImportChecker:
-    """Check all executors, drivers and handler functions in the package. """
+    """Check all executors, drivers and handler functions in the package."""
 
     def __init__(self, args: 'argparse.Namespace'):
+        """
+        Create a new :class:`ImportChecker`.
+
+        :param args: args provided by the CLI.
+        """
         default_logger.info('\navailable core executors\n'.upper())
 
         _r = import_classes('jina.executors', show_import_table=True, import_once=False)
@@ -29,7 +34,7 @@ class ImportChecker:
 
         _r = import_classes('jina.hub', show_import_table=True, import_once=False)
 
-        if args.summary_exec:
+        if args.summary_exec and _r:
             with open(args.summary_exec, 'w') as fp:
                 _print_dep_tree_rst(fp, _r, 'Executor')
 
@@ -48,10 +53,15 @@ class ImportChecker:
 
 
 class NetworkChecker:
-    """Check if a BasePod is running or not """
+    """Check if a BasePod is running or not."""
 
     def __init__(self, args: 'argparse.Namespace'):
-        from .peapods.peas import send_ctrl_message
+        """
+        Create a new :class:`NetworkChecker`.
+
+        :param args: args provided by the CLI.
+        """
+        from .peapods.zmq import send_ctrl_message
         from .logging.profile import TimeContext
         from google.protobuf.json_format import MessageToJson
         import time
@@ -67,7 +77,7 @@ class NetworkChecker:
                     else:
                         total_success += 1
                         if args.print_response:
-                            default_logger.info(f'returns {MessageToJson(r.as_pb_object)}')
+                            default_logger.info(f'returns {MessageToJson(r.proto)}')
                 total_time += tc.duration
                 time.sleep(1)
             if total_success < args.retries:
