@@ -1,30 +1,31 @@
-import json
+"""Module wrapping interactions with the remote Jina Hub."""
 import base64
+import json
+from typing import Dict, Sequence, Any, Optional, List, Tuple
 from urllib.error import HTTPError
 from urllib.parse import urlencode
 from urllib.request import Request, urlopen
-from pkg_resources import resource_stream
-from typing import Dict, Sequence, Any, Optional, List
 
-from ...jaml import JAML
+from pkg_resources import resource_stream
+
+from .local import _fetch_access_token, _make_hub_table, _make_hub_table_with_local, _load_local_hub_manifest
 from ...helper import colored
 from ...importer import ImportExtensions
+from ...jaml import JAML
 from ...logging.profile import TimeContext
-from .local import _fetch_access_token, _make_hub_table, _make_hub_table_with_local, _load_local_hub_manifest
 
 
 def _list(logger, image_name: str = None, image_kind: str = None,
           image_type: str = None, image_keywords: Sequence = ()) -> Optional[List[Dict[str, Any]]]:
-    """ Use Hub api to get the list of filtered images
+    """Use Hub api to get the list of filtered images.
 
     :param logger: logger to use
-    :param image_name:
-    :param image_kind:
-    :param image_type:
-    :param image_keywords:
+    :param image_name: name of hub image
+    :param image_kind: kind of hub image (indexer/encoder/segmenter/crafter/evaluator/ranker etc)
+    :param image_type: type of hub image (pod/app)
+    :param image_keywords: keywords added in the manifest yml
     :return: a dict of manifest specifications, each coresponds to a hub image
     """
-    # TODO: Shouldn't pass a default argument for keywords. Need to handle after lambda function gets fixed
     with resource_stream('jina', '/'.join(('resources', 'hubapi.yml'))) as fp:
         hubapi_yml = JAML.load(fp)
         hubapi_url = hubapi_yml['hubapi']['url'] + hubapi_yml['hubapi']['list']
@@ -33,11 +34,11 @@ def _list(logger, image_name: str = None, image_kind: str = None,
         'name': image_name,
         'kind': image_kind,
         'type': image_type,
-        'keywords': ','.join(image_keywords) if image_keywords else None
+        'keywords': image_keywords
     }
     params = {k: v for k, v in params.items() if v}
     if params:
-        data = urlencode(params)
+        data = urlencode(params, doseq=True)
         request = Request(f'{hubapi_url}?{data}')
         with TimeContext('searching', logger):
             try:
@@ -52,19 +53,19 @@ def _list(logger, image_name: str = None, image_kind: str = None,
                     logger.error(f'unknown error: {err.reason}')
                 return
 
-        manifests = response['manifest']
         local_manifest = _load_local_hub_manifest()
         if local_manifest:
-            tb = _make_hub_table_with_local(manifests, local_manifest)
+            tb = _make_hub_table_with_local(response, local_manifest)
         else:
-            tb = _make_hub_table(manifests)
+            tb = _make_hub_table(response)
         logger.info('\n'.join(tb))
-        return manifests
+        return response
 
 
-def _fetch_docker_auth(logger) -> Optional[Dict[str, str]]:
-    """ Use Hub api to get docker creds
+def _fetch_docker_auth(logger) -> Tuple[str, str]:
+    """Use Hub api to get docker credentials.
 
+    :param logger: the logger instance
     :return: a dict of specifying username and password
     """
     with resource_stream('jina', '/'.join(('resources', 'hubapi.yml'))) as fp:
@@ -93,7 +94,11 @@ def _fetch_docker_auth(logger) -> Optional[Dict[str, str]]:
 
 
 def _register_to_mongodb(logger, summary: Dict = None):
-    """ Hub API Invocation to run `hub push` """
+    """Hub API Invocation to run `hub push`.
+
+    :param logger: the logger instance
+    :param summary: the summary dict object
+    """
     logger.info('registering image to Jina Hub database...')
 
     with resource_stream('jina', '/'.join(('resources', 'hubapi.yml'))) as fp:
