@@ -29,9 +29,9 @@ if False:
     from ..executors import AnyExecutor
     from ..logging.logger import JinaLogger
     from ..types.message import Message
-    from ..types.document import Document
     from ..types.request import Request
     from ..types.sets import QueryLangSet, DocumentSet
+    from ..types.document import Document
 
 
 def store_init_kwargs(func: Callable) -> Callable:
@@ -220,13 +220,6 @@ class BaseDriver(JAMLCompatible, metaclass=DriverType):
         else:
             return []
 
-    @property
-    def docs(self):
-        if self.expect_parts > 1:
-            return (d for r in reversed(self.partial_reqs) for d in r.docs)
-        else:
-            return self.req.docs
-
     @property
     def logger(self) -> 'JinaLogger':
         """Shortcut to ``self.runtime.logger``"""
@@ -235,15 +228,6 @@ class BaseDriver(JAMLCompatible, metaclass=DriverType):
     def __call__(self, *args, **kwargs) -> None:
         raise NotImplementedError
 
-    @staticmethod
-    def _dump_instance_to_yaml(data) -> Dict[str, Dict]:
-        # note: we only save non-default property for the sake of clarity
-        a = {k: v for k, v in data._init_kwargs_dict.items()}
-        r = {}
-        if a:
-            r['with'] = a
-        return r
-
     def __eq__(self, other):
         return self.__class__ == other.__class__
 
@@ -269,6 +253,13 @@ class BaseRecursiveDriver(BaseDriver):
         super().__init__(*args, **kwargs)
         self._traversal_paths = [path.lower() for path in traversal_paths]
 
+    @property
+    def docs(self):
+        if self.expect_parts > 1:
+            return (d for r in reversed(self.partial_reqs) for d in r.docs)
+        else:
+            return self.req.docs
+
     def _apply_root(
         self,
         docs: 'DocumentSet',
@@ -330,6 +321,31 @@ class BaseRecursiveDriver(BaseDriver):
             self._apply_all(docs, parent_doc, parent_edge_type, *args, **kwargs)
 
 
+class FastRecursiveMixin:
+    """
+    The optimized version of :class:`BaseRecursiveDriver`,
+     it uses :meth:`traverse` in :class:`DocumentSet` and yield much better performance for index and encode drivers.
+
+     .. seealso::
+        https://github.com/jina-ai/jina/issues/1932
+
+    """
+
+    def __call__(self, *args, **kwargs):
+        self._apply_all(self.docs, *args, **kwargs)
+
+    @property
+    def docs(self) -> 'DocumentSet':
+        from ..types.sets import DocumentSet
+
+        if self.expect_parts > 1:
+            return DocumentSet(
+                (d for r in reversed(self.partial_reqs) for d in r.docs)
+            ).traverse(self._traversal_paths)
+        else:
+            return self.req.docs.traverse(self._traversal_paths)
+
+
 class BaseExecutableDriver(BaseRecursiveDriver):
     """A :class:`BaseExecutableDriver` is an intermediate logic unit between the :class:`jina.peapods.runtimes.zmq.zed.ZEDRuntime` and :class:`jina.executors.BaseExecutor`
     It reads the protobuf message, extracts/modifies the required information and then sends to the :class:`jina.executors.BaseExecutor`,
