@@ -3,7 +3,7 @@ __license__ = "Apache-2.0"
 
 from typing import Tuple
 
-from . import BaseExecutableDriver, QuerySetReader
+from . import BaseExecutableDriver, QuerySetReader, FastRecursiveMixin
 from ..types.document import Document
 from ..types.score import NamedScore
 
@@ -49,17 +49,17 @@ class KVSearchDriver(BaseSearchDriver):
             - K is the top-k
     """
 
-    def __init__(self, is_merge: bool = True, traversal_paths: Tuple[str] = ('m'), *args, **kwargs):
+    def __init__(self, is_update: bool = True, traversal_paths: Tuple[str] = ('m'), *args, **kwargs):
         """Construct the driver.
 
-        :param is_merge: when set to true the retrieved docs are merged into current message using :meth:`MergeFrom`,
-            otherwise, it overrides the current message using :meth:`CopyFrom`
+        :param is_update: when set to true the retrieved docs are merged into current message;
+            otherwise, the retrieved Document overrides the existing Document
         :param traversal_paths: traversal paths for the driver
         :param *args: *args for super
         :param **kwargs: **kwargs for super
         """
         super().__init__(traversal_paths=traversal_paths, *args, **kwargs)
-        self._is_merge = is_merge
+        self._is_update = is_update
 
     def _apply_all(self, docs: 'DocumentSet', *args, **kwargs) -> None:
         miss_idx = []  #: missed hit results, some search may not end with results. especially in shards
@@ -67,11 +67,8 @@ class KVSearchDriver(BaseSearchDriver):
             serialized_doc = self.exec_fn(retrieved_doc.id)
             if serialized_doc:
                 r = Document(serialized_doc)
-
-                # TODO: this isn't perfect though, merge applies recursively on all children
-                #  it will duplicate embedding.shape if embedding is already there
-                if self._is_merge:
-                    retrieved_doc.MergeFrom(r)
+                if self._is_update:
+                    retrieved_doc.update(r)
                 else:
                     retrieved_doc.CopyFrom(r)
             else:
@@ -94,7 +91,7 @@ class VectorFillDriver(QuerySetReader, BaseSearchDriver):
             doc.embedding = embedding
 
 
-class VectorSearchDriver(QuerySetReader, BaseSearchDriver):
+class VectorSearchDriver(FastRecursiveMixin, QuerySetReader, BaseSearchDriver):
     """Extract embeddings from the request for the executor to query.
     """
 
@@ -112,7 +109,7 @@ class VectorSearchDriver(QuerySetReader, BaseSearchDriver):
         self._fill_embedding = fill_embedding
 
     def _apply_all(self, docs: 'DocumentSet', *args, **kwargs) -> None:
-        embed_vecs, doc_pts, bad_docs = docs.all_embeddings
+        embed_vecs, doc_pts = docs.all_embeddings
 
         if not doc_pts:
             return
@@ -121,8 +118,6 @@ class VectorSearchDriver(QuerySetReader, BaseSearchDriver):
         if self._fill_embedding and not fill_fn:
             self.logger.warning(f'"fill_embedding=True" but {self.exec} does not have "query_by_key" method')
 
-        if bad_docs:
-            self.logger.warning(f'these bad docs can not be added: {bad_docs}')
         idx, dist = self.exec_fn(embed_vecs, top_k=int(self.top_k))
 
         op_name = self.exec.__class__.__name__
