@@ -1,6 +1,5 @@
 """
-Miscellaneous enums used in jina
-
+Miscellaneous enums used in Jina.
 
 To use these enums in YAML config, following the example below:
 
@@ -23,7 +22,6 @@ To use these enums in YAML config, following the example below:
       chunk_idx:
         uses: index/chunk.yml
         parallel: ${{PARALLEL}}
-        separated_workspace: true
         parallel_type: !PollingType ANY
         # or
         parallel_type: ANY
@@ -38,6 +36,7 @@ from enum import IntEnum, EnumMeta
 
 
 class EnumType(EnumMeta):
+    """The metaclass for BetterEnum."""
 
     def __new__(cls, *args, **kwargs):
         _cls = super().__new__(cls, *args, **kwargs)
@@ -45,6 +44,12 @@ class EnumType(EnumMeta):
 
     @staticmethod
     def register_class(cls):
+        """
+        Register the class for dumping loading.
+
+        :param cls: Target class.
+        :return: Registered class.
+        """
         reg_cls_set = getattr(cls, '_registered_class', set())
         if cls.__name__ not in reg_cls_set or getattr(cls, 'force_register', False):
             reg_cls_set.add(cls.__name__)
@@ -55,20 +60,22 @@ class EnumType(EnumMeta):
 
 
 class BetterEnum(IntEnum, metaclass=EnumType):
+    """The base class of Enum used in Jina."""
+
     def __str__(self):
         return self.name
 
     @classmethod
     def from_string(cls, s: str):
-        """Parse the enum from a string"""
+        """Parse the enum from a string."""
         try:
             return cls[s.upper()]
         except KeyError:
-            raise ValueError(f'{s.upper()} is not a valid enum for {cls}')
+            raise ValueError(f'{s.upper()} is not a valid enum for {cls!r}, must be one of {list(cls)}')
 
     @classmethod
     def _to_yaml(cls, representer, data):
-        """Required by :mod:`pyyaml`
+        """Required by :mod:`pyyaml`.
 
         .. note::
             In principle, this should inherit from :class:`JAMLCompatible` directly,
@@ -78,7 +85,7 @@ class BetterEnum(IntEnum, metaclass=EnumType):
 
     @classmethod
     def _from_yaml(cls, constructor, node):
-        """Required by :mod:`pyyaml`
+        """Required by :mod:`pyyaml`.
 
         .. note::
             In principle, this should inherit from :class:`JAMLCompatible` directly,
@@ -88,44 +95,49 @@ class BetterEnum(IntEnum, metaclass=EnumType):
 
 
 class SchedulerType(BetterEnum):
+    """The enum for Scheduler Type."""
+
     LOAD_BALANCE = 0  #: balance the workload between Peas, faster peas get more work
-    ROUND_ROBIN = 1  #: workload are scheduled round-robin manner to the peas, assuming all peas have uniform processing speed.
+    ROUND_ROBIN = 1  # : workload are scheduled round-robin manner to the peas, assuming all peas have uniform processing speed.
 
 
 class PollingType(BetterEnum):
-    """The enum for representing the parallel type of peas in a pod
+    """The enum for representing the parallel type of peas in a pod."""
 
-    """
-    ANY = 1  #: one of the replica will receive the message
-    ALL = 2  #: all replica will receive the message, blocked until all done with the message
+    ANY = 1  #: one of the shards will receive the message
+    ALL = 2  #: all shards will receive the message, blocked until all done with the message
     ALL_ASYNC = 3  #: (reserved) all replica will receive the message, but any one of them can return, useful in backup
 
     @property
     def is_push(self) -> bool:
         """
+        Check if :class:`PollingType` is using `push` protocol.
 
-        :return: if this :class:`PollingType` is using `push` protocol
+        :return: True if this :class:`PollingType` is using `push` protocol else False.
         """
         return self.value == 1
 
     @property
     def is_block(self) -> bool:
         """
+        Check if :class:`PollingType` is using `block` protocol.
 
-        :return: if this :class:`PollingType` is requiring `block` protocol
+        :return: True if this :class:`PollingType` is requiring `block` protocol else False.
         """
         return self.value == 2
 
 
 class FlowOptimizeLevel(BetterEnum):
-    """The level of flow optimization """
+    """The level of flow optimization."""
+
     NONE = 0
     IGNORE_GATEWAY = 1
     FULL = 2
 
 
 class LogVerbosity(BetterEnum):
-    """Verbosity level of the logger """
+    """Verbosity level of the logger."""
+
     DEBUG = 10
     INFO = 20
     SUCCESS = 25
@@ -135,7 +147,8 @@ class LogVerbosity(BetterEnum):
 
 
 class SocketType(BetterEnum):
-    """Enums for representing the socket type in a pod """
+    """Enums for representing the socket type in a pod."""
+
     PULL_BIND = 0
     PULL_CONNECT = 1
     PUSH_BIND = 2
@@ -152,32 +165,36 @@ class SocketType(BetterEnum):
     @property
     def is_bind(self) -> bool:
         """
+        Check if this socket is using `bind` protocol.
 
-        :return: if this socket is using `bind` protocol
+        :return: True if this socket is using `bind` protocol else False.
         """
         return self.value % 2 == 0
 
     @property
     def is_receive(self) -> bool:
         """
+        Check if this socket is used for receiving data.
 
-        :return: if this socket is used for receiving data
+        :return: True if this socket is used for receiving data else False.
         """
         return self.value in {0, 1, 4, 5}
 
     @property
     def is_pubsub(self):
         """
+        Check if this socket is used for publish or subscribe data.
 
-        :return: if this socket is used for publish or subscribe data
+        :return: True if this socket is used for publish or subscribe data else False.
         """
         return 4 <= self.value <= 7
 
     @property
     def paired(self) -> 'SocketType':
         """
+        Get the paired SocketType.
 
-        :return: a paired
+        :return: a paired SocketType.
         """
         return {
             SocketType.PULL_BIND: SocketType.PUSH_CONNECT,
@@ -194,7 +211,8 @@ class SocketType(BetterEnum):
 
 
 class FlowOutputType(BetterEnum):
-    """The enum for representing flow output config """
+    """The enum for representing flow output config."""
+
     SHELL_PROC = 0  #: a shell-script, run each microservice as a process
     SHELL_DOCKER = 1  #: a shell-script, run each microservice as a container
     DOCKER_SWARM = 2  #: a docker-swarm YAML config
@@ -202,18 +220,19 @@ class FlowOutputType(BetterEnum):
 
 
 class FlowBuildLevel(BetterEnum):
-    """The enum for representing a flow's build level
+    """
+    The enum for representing a flow's build level.
 
     Some :class:`jina.flow.Flow` class functions require certain build level to run.
     """
+
     EMPTY = 0  #: Nothing is built
     GRAPH = 1  #: The underlying graph is built, you may visualize the flow
 
 
 class PeaRoleType(BetterEnum):
-    """ The enum of a Pea role
+    """The enum of a Pea role."""
 
-    """
     SINGLETON = 0
     HEAD = 1
     TAIL = 2
@@ -221,9 +240,8 @@ class PeaRoleType(BetterEnum):
 
 
 class PodRoleType(BetterEnum):
-    """ The enum of a Pod role for visualization
+    """The enum of a Pod role for visualization."""
 
-    """
     POD = 0
     JOIN = 1
     INSPECT = 2
@@ -234,17 +252,16 @@ class PodRoleType(BetterEnum):
     @property
     def is_inspect(self) -> bool:
         """
-        if the role is inspect pod related
+        If the role is inspect pod related.
 
-        :return:
+        :return: True if the Pod role is inspect related else False.
         """
         return self.value in {2, 4}
 
 
 class RequestType(BetterEnum):
-    """ The enum of Client mode
+    """The enum of Client mode."""
 
-    """
     INDEX = 0
     SEARCH = 1
     DELETE = 2
@@ -254,7 +271,8 @@ class RequestType(BetterEnum):
 
 
 class CompressAlgo(BetterEnum):
-    """ The enum of Compress algorithms
+    """
+    The enum of Compress algorithms.
 
     .. note::
         LZ4 requires additional package, to install it use pip install "jina[lz4]"
@@ -263,6 +281,7 @@ class CompressAlgo(BetterEnum):
 
         https://docs.python.org/3/library/archiving.html
     """
+
     NONE = 0
     LZ4 = 1
     ZLIB = 2
@@ -271,8 +290,9 @@ class CompressAlgo(BetterEnum):
     LZMA = 5
 
 
-class SkipOnErrorType(BetterEnum):
-    """ The level of error handling
+class OnErrorStrategy(BetterEnum):
+    """
+    The level of error handling.
 
     .. warning::
         In theory, all methods below do not 100% guarantee the success
@@ -281,14 +301,14 @@ class SkipOnErrorType(BetterEnum):
         side-effect.
     """
 
-    NONE = 0  # do not skip on error, keep running the original executor & driver logics
-    EXECUTOR = 1  # skip the executor on error, but driver is still called, no error message is labeled
-    HANDLE = 2  # skip the handle on error, no driver and executor is called, pre_hook and post_hook are called
+    IGNORE = 0  #: Ignore it, keep running all Drivers & Executors logics in the sequel flow
+    SKIP_EXECUTOR = 1  #: Skip all Executors in the sequel, but drivers are still called
+    SKIP_HANDLE = 2  #: Skip all Drivers & Executors in the sequel, only `pre_hook` and `post_hook` are called
+    THROW_EARLY = 3  #: Immediately throw the exception, the sequel flow will not be running at all
 
 
 class FlowInspectType(BetterEnum):
-    """ Inspect strategy in the flow
-    """
+    """Inspect strategy in the flow."""
 
     HANG = 0  # keep them hanging there
     REMOVE = 1  # remove them in the build
@@ -297,28 +317,22 @@ class FlowInspectType(BetterEnum):
     @property
     def is_keep(self) -> bool:
         """
+        Check if the target is inspected.
 
-        :return: if this socket is using `bind` protocol
+        :return: True if the target is inspected else False.
         """
         return self.value in {0, 2}
 
 
 class RemoteAccessType(BetterEnum):
-    """Remote access type when connect to the host """
+    """Remote access type when connect to the host."""
 
     SSH = 0  # ssh connection
     JINAD = 1  # using rest api via jinad
 
 
-class RemotePeapodType(BetterEnum):
-    """Remote access type when connect to the host """
-
-    PEA = 0
-    POD = 1
-
-
 class BuildTestLevel(BetterEnum):
-    """Test level in :command:`jina hub build`, higher level includes lower levels """
+    """Test level in :command:`jina hub build`, higher level includes lower levels."""
 
     NONE = 0  # no build test
     EXECUTOR = 1  # test at executor level, directly use the config yaml
@@ -328,7 +342,7 @@ class BuildTestLevel(BetterEnum):
 
 
 class DataInputType(BetterEnum):
-    """Data input type in the request generator """
+    """Data input type in the request generator."""
 
     AUTO = 0  # auto inference the input type from data (!WARN: could be slow as it relies on try-execept)
     DOCUMENT = 1  # the input is a full document
@@ -336,5 +350,22 @@ class DataInputType(BetterEnum):
 
 
 class RuntimeBackendType(BetterEnum):
+    """Type of backend in runtime."""
+
     THREAD = 0
     PROCESS = 1
+
+
+def replace_enum_to_str(obj):
+    """
+    Transform BetterEnum type into string.
+
+    :param obj: Target obj.
+    :return: Transformed obj with string type values.
+    """
+    for k, v in obj.items():
+        if isinstance(v, dict):
+            obj[k] = replace_enum_to_str(v)
+        elif isinstance(v, BetterEnum):
+            obj[k] = str(v)
+    return obj
