@@ -1,3 +1,5 @@
+"""Indexer for caching."""
+
 import pickle
 import tempfile
 from typing import Optional, Iterable
@@ -10,27 +12,38 @@ CONTENT_HASH_KEY = 'content_hash'
 
 
 class BaseCache(BaseKVIndexer):
-    """Base class of the cache inherited :class:`BaseKVIndexer`
+    """Base class of the cache inherited :class:`BaseKVIndexer`.
 
-    The difference between a cache and a :class:`BaseKVIndexer` is the ``handler_mutex`` is released in cache, this allows one to query-while-indexing.
+    The difference between a cache and a :class:`BaseKVIndexer` is the ``handler_mutex`` is released in cache,
+    this allows one to query-while-indexing.
     """
 
     def __init__(self, *args, **kwargs):
+        """Create a new BaseCache."""
         super().__init__(*args, **kwargs)
 
     def post_init(self):
-        self.handler_mutex = False  #: for Cache we need to release the handler mutex to allow RW at the same time
+        """For Cache we need to release the handler mutex to allow RW at the same time."""
+        self.handler_mutex = False
 
 
 class DocCache(BaseCache):
     """A key-value indexer that specializes in caching.
+
     Serializes the cache to two files, one for ids, one for the actually cached field.
     If field=`id`, then the second file is redundant. The class optimizes the process
     so that there are no duplicates.
     """
 
     class CacheHandler:
+        """A handler for loading and serializing the in-memory cache of the DocCache."""
+
         def __init__(self, path, logger):
+            """Create a new CacheHandler.
+
+            :param path: Path to the file from which to build the actual paths.
+            :param logger: Instance of logger.
+            """
             self.path = path
             try:
                 self.id_to_cache_val = pickle.load(open(path + '.ids', 'rb'))
@@ -42,6 +55,7 @@ class DocCache(BaseCache):
                 self.cache_val_to_id = dict()
 
         def close(self):
+            """Flushes the in-memory cache to pickle files."""
             pickle.dump(self.id_to_cache_val, open(self.path + '.ids', 'wb'))
             pickle.dump(self.cache_val_to_id, open(self.path + '.cache', 'wb'))
 
@@ -49,7 +63,7 @@ class DocCache(BaseCache):
     default_field = ID_KEY
 
     def __init__(self, index_filename: Optional[str] = None, field: Optional[str] = None, *args, **kwargs):
-        """ Create a new DocCache
+        """Create a new DocCache.
 
         :param index_filename: file name for storing the cache data
         :param field: field to cache on (ID_KEY or CONTENT_HASH_KEY)
@@ -62,31 +76,31 @@ class DocCache(BaseCache):
         if self.field not in self.supported_fields:
             raise ValueError(f"Field '{self.field}' not in supported list of {self.supported_fields}")
 
-    def add(self, doc_id: str, *args, **kwargs):
-        """Add a document to the cache depending on `self.field`.
+    def add(self, keys: Iterable[str], values: Iterable[str], *args, **kwargs) -> None:
+        """Add a document to the cache depending.
 
-        :param doc_id: document id to be added
+        :param keys: document ids to be added
+        :param values: document cache values to be added
         """
-        if self.field != ID_KEY:
-            data = kwargs.get(DATA_FIELD, None)
-        else:
-            data = doc_id
-        self.query_handler.id_to_cache_val[doc_id] = data
-        self.query_handler.cache_val_to_id[data] = doc_id
-        self._size += 1
+        for key, value in zip(keys, values):
+            self.query_handler.id_to_cache_val[key] = value
+            self.query_handler.cache_val_to_id[value] = key
+            self._size += 1
 
-    def query(self, data: str, *args, **kwargs) -> Optional[bool]:
+    def query(self, key: str, *args, **kwargs) -> bool:
         """Check whether the data exists in the cache.
 
-        :param data: either the id or the content_hash of a Document
+        :param key: either the id or the content_hash of a Document
         :return: status
         """
-        return data in self.query_handler.cache_val_to_id
+        return key in self.query_handler.cache_val_to_id
 
-    def update(self, keys: Iterable[str], values: Iterable[any], *args, **kwargs):
+    def update(self, keys: Iterable[str], values: Iterable[str], *args, **kwargs) -> None:
         """Update cached documents.
+
         :param keys: list of Document.id
-        :param values: list of either `id` or `content_hash` of :class:`Document`"""
+        :param values: list of either `id` or `content_hash` of :class:`Document`
+        """
         # if we don't cache anything else, no need
         if self.field != ID_KEY:
             for key, value in zip(keys, values):
@@ -97,8 +111,9 @@ class DocCache(BaseCache):
                 del self.query_handler.cache_val_to_id[old_value]
                 self.query_handler.cache_val_to_id[value] = key
 
-    def delete(self, keys: Iterable[str], *args, **kwargs):
+    def delete(self, keys: Iterable[str], *args, **kwargs) -> None:
         """Delete documents from the cache.
+
         :param keys: list of Document.id
         """
         for key in keys:
@@ -110,14 +125,13 @@ class DocCache(BaseCache):
             self._size -= 1
 
     def get_add_handler(self):
-        # not needed, as we use the queryhandler
-        # FIXME better way to silence warnings
-        return 1
+        """Get the CacheHandler."""
+        return self.get_query_handler()
 
     def get_query_handler(self) -> CacheHandler:
-        return self.CacheHandler(self.index_abspath, self.logger)
+        """Get the CacheHandler."""
+        return self.CacheHandler(self.save_abspath, self.logger)
 
     def get_create_handler(self):
-        # not needed, as we use the queryhandler
-        # FIXME better way to silence warnings
-        return 1
+        """Get the CacheHandler."""
+        return self.get_query_handler()
