@@ -2,10 +2,11 @@ __copyright__ = "Copyright (c) 2020 Jina AI Limited. All rights reserved."
 __license__ = "Apache-2.0"
 
 import gzip
+import io
 import os
 from functools import lru_cache
 from os import path
-from typing import Optional, Iterable, Tuple, Dict, Sequence
+from typing import Optional, Iterable, Tuple, Dict
 
 import numpy as np
 
@@ -55,7 +56,7 @@ class BaseNumpyIndexer(BaseVectorIndexer):
             self.dtype = ref_indexer.dtype
             self.compress_level = ref_indexer.compress_level
             self.key_bytes = ref_indexer.key_bytes
-            self._key_length = ref_indexer._key_length
+            self.key_length = ref_indexer.key_length
             self._size = ref_indexer._size
             # point to the ref_indexer.index_filename
             # so that later in `post_init()` it will load from the referred index_filename
@@ -82,8 +83,8 @@ class BaseNumpyIndexer(BaseVectorIndexer):
         """
         return self.get_file_from_workspace(self.index_filename)
 
-    def get_add_handler(self):
-        """Open a binary gzip file for adding new vectors
+    def get_add_handler(self) -> 'io.BufferedWriter':
+        """Open a binary gzip file for appending new vectors
 
         :return: a gzip file stream
         """
@@ -92,8 +93,8 @@ class BaseNumpyIndexer(BaseVectorIndexer):
         else:
             return open(self.index_abspath, 'ab')
 
-    def get_create_handler(self):
-        """Create a new gzip file for adding new vectors
+    def get_create_handler(self) -> 'io.BufferedWriter':
+        """Create a new gzip file for adding new vectors. The old vectors are replaced.
 
         :return: a gzip file stream
         """
@@ -115,7 +116,8 @@ class BaseNumpyIndexer(BaseVectorIndexer):
         elif self.dtype != vectors.dtype.name:
             raise TypeError(
                 f'vectors\' dtype {vectors.dtype.name} does not match with indexers\'s dtype: {self.dtype}')
-        elif keys.shape[0] != vectors.shape[0]:
+
+        if keys.shape[0] != vectors.shape[0]:
             raise ValueError(f'number of key {keys.shape[0]} not equal to number of vectors {vectors.shape[0]}')
 
     def add(self, keys: Iterable[str], vectors: 'np.ndarray', *args, **kwargs) -> None:
@@ -124,32 +126,32 @@ class BaseNumpyIndexer(BaseVectorIndexer):
         :param keys: a list of ``id``, i.e. ``doc.id`` in protobuf
         :param vectors: embeddings
         """
-        self._assert_key_length(keys)
-
         np_keys = np.array(keys, (np.str_, self.key_length))
-
         self._add(np_keys, vectors)
 
     def _add(self, keys: 'np.ndarray', vectors: 'np.ndarray'):
-        self._validate_key_vector_shapes(keys, vectors)
-        self.write_handler.write(vectors.tobytes())
-        self.valid_indices = np.concatenate((self.valid_indices, np.full(len(keys), True)))
-        self.key_bytes += keys.tobytes()
-        self._size += keys.shape[0]
+        if keys.size and vectors.size:
+            self._validate_key_vector_shapes(keys, vectors)
+            self.write_handler.write(vectors.tobytes())
+            self.valid_indices = np.concatenate((self.valid_indices, np.full(len(keys), True)))
+            self.key_bytes += keys.tobytes()
+            self._size += keys.shape[0]
 
-    def update(self, keys: Iterable[str], values: Sequence[bytes], *args, **kwargs) -> None:
+    def update(self, keys: Iterable[str], vectors: 'np.ndarray', *args, **kwargs) -> None:
         """Update the embeddings on the index via document ids.
 
         :param keys: a list of ``id``, i.e. ``doc.id`` in protobuf
-        :param values: embeddings
+        :param vectors: embeddings
         """
         # noinspection PyTypeChecker
-        keys, values = self._filter_nonexistent_keys_values(keys, values, self._ext2int_id.keys())
-        np_keys = np.array(keys, (np.str_, self.key_length))
-
-        if np_keys.size:
-            self._delete(np_keys)
-            self._add(np_keys, np.array(values))
+        if self.size:
+            keys, values = self._filter_nonexistent_keys_values(keys, vectors, self._ext2int_id.keys())
+            if keys:
+                np_keys = np.array(keys, (np.str_, self.key_length))
+                self._delete(np_keys)
+                self._add(np_keys, np.array(values))
+        else:
+            self.logger.error(f'{self!r} is empty, update is aborted')
 
     def _delete(self, keys):
         if keys.size:
@@ -163,9 +165,13 @@ class BaseNumpyIndexer(BaseVectorIndexer):
 
         :param keys: a list of ``id``, i.e. ``doc.id`` in protobuf
         """
-        keys = self._filter_nonexistent_keys(keys, self._ext2int_id.keys())
-        np_keys = np.array(keys, (np.str_, self.key_length))
-        self._delete(np_keys)
+        if self.size:
+            keys = self._filter_nonexistent_keys(keys, self._ext2int_id.keys())
+            if keys:
+                np_keys = np.array(keys, (np.str_, self.key_length))
+                self._delete(np_keys)
+        else:
+            self.logger.error(f'{self!r} is empty, deletion is aborted')
 
     def get_query_handler(self) -> Optional['np.ndarray']:
         """Open a gzip file and load it as a numpy ndarray
@@ -211,7 +217,7 @@ class BaseNumpyIndexer(BaseVectorIndexer):
             return np.memmap(self.index_abspath, dtype=self.dtype, mode='r',
                              shape=(self.size + deleted_keys, self.num_dim))
 
-    def query_by_key(self, keys: Sequence[str], *args, **kwargs) -> Optional['np.ndarray']:
+    def query_by_key(self, keys: Iterable[str], *args, **kwargs) -> Optional['np.ndarray']:
         """
         Search the index by the external key (passed during `.add(`).
 
@@ -327,8 +333,7 @@ class NumpyIndexer(BaseNumpyIndexer):
 
         return idx, dist
 
-    def query(self, query_vectors: 'np.ndarray', top_k: int, *args, **kwargs) -> Tuple[
-        Optional['np.ndarray'], Optional['np.ndarray']]:
+    def query(self, vectors: 'np.ndarray', top_k: int, *args, **kwargs) -> Tuple['np.ndarray', 'np.ndarray']:
         """Find the top-k vectors with smallest ``metric`` and return their ids in ascending order.
 
         :return: a tuple of two ndarray.
@@ -341,14 +346,14 @@ class NumpyIndexer(BaseNumpyIndexer):
 
         """
         if self.size == 0:
-            return None, None
+            return np.array([]), np.array([])
         if self.metric not in {'cosine', 'euclidean'} or self.backend == 'scipy':
-            dist = self._cdist(query_vectors, self.query_handler)
+            dist = self._cdist(vectors, self.query_handler)
         elif self.metric == 'euclidean':
-            _query_vectors = _ext_A(query_vectors)
+            _query_vectors = _ext_A(vectors)
             dist = self._euclidean(_query_vectors, self.query_handler)
         elif self.metric == 'cosine':
-            _query_vectors = _ext_A(_norm(query_vectors))
+            _query_vectors = _ext_A(_norm(vectors))
             dist = self._cosine(_query_vectors, self.query_handler)
         else:
             raise NotImplementedError(f'{self.metric} is not implemented')
@@ -357,7 +362,7 @@ class NumpyIndexer(BaseNumpyIndexer):
         indices = self._int2ext_id[self.valid_indices][idx]
         return indices, dist
 
-    def build_advanced_index(self, vecs: 'np.ndarray'):
+    def build_advanced_index(self, vecs: 'np.ndarray') -> 'np.ndarray':
         return vecs
 
     @batching(merge_over_axis=1, slice_on=2)
