@@ -16,11 +16,7 @@ class BaseSegmenter(BaseExecutor):
             self.logger.warning(f'{typename(self)} works on keys, but no keys are specified')
 
     def segment(self, *args, **kwargs) -> List[Dict]:
-        """The apply function of this executor.
-        Unlike :class:`BaseCrafter`, the :func:`craft` here works on doc-level info and the output is defined on
-        chunk-level. Therefore the name of the arguments should be always valid keys defined
-        in the doc-level protobuf whereas the output dict keys should always be valid keys defined in the chunk-level
-        protobuf.
+        """
         :return: a list of chunks-level info represented by a dict
         """
         raise NotImplementedError
