@@ -77,15 +77,19 @@ class ScannIndexer(BaseNumpyIndexer):
         Then the top-k from this new measurement will be selected.
         """
         import scann
-        index = scann.ScannBuilder(vecs, self.training_iterations, self.distance_measure). \
+        index = scann.scann_ops_pybind.builder(vecs, self.training_iterations, self.distance_measure). \
             score_ah(self.dimensions_per_block, self.anisotropic_quantization_threshold). \
-            reorder(self.reordering_num_neighbors).create_pybind()
+            reorder(self.reordering_num_neighbors).build()
         return index
 
     def query(self, keys: 'np.ndarray', top_k: int, *args, **kwargs) -> Tuple['np.ndarray', 'np.ndarray']:
+        """Find the top-k vectors with smallest ``metric`` and return their ids in ascending order.
+        :param keys: numpy array containing vectors to search for
+        :param top_k: upper limit of responses for each search vector
+        """
         if self.reordering_num_neighbors < top_k:
             self.logger.warning('The number of reordering_num_neighbors should be the same or higher than top_k')
 
         neighbors, dist = self.query_handler.search_batched(keys, top_k)
-        return self.int2ext_id[np.array(neighbors)], np.array(dist)
+        return self._int2ext_id[np.array(neighbors)], np.array(dist)
 
